@@ -3,15 +3,15 @@
 https://www.ibm.com/docs/en/i/7.4?topic=overview-db2-i
 """
 
-from sqlfluff.core.parser import (
-    SegmentGenerator,
-    RegexParser,
-    CodeSegment,
-    RegexLexer,
-    CommentSegment,
-)
-
 from sqlfluff.core.dialects import load_raw_dialect
+from sqlfluff.core.parser import (
+    CodeSegment,
+    CommentSegment,
+    RegexLexer,
+    RegexParser,
+    SegmentGenerator,
+)
+from sqlfluff.dialects import dialect_ansi as ansi
 
 ansi_dialect = load_raw_dialect("ansi")
 
@@ -24,9 +24,8 @@ db2_dialect.replace(
         # Generate the anti template from the set of reserved keywords
         lambda dialect: RegexParser(
             r"[A-Z0-9_#]*[A-Z#][A-Z0-9_#]*",
-            CodeSegment,
-            name="naked_identifier",
-            type="identifier",
+            ansi.IdentifierSegment,
+            type="naked_identifier",
             anti_template=r"^(" + r"|".join(dialect.sets("reserved_keywords")) + r")$",
         )
     ),
@@ -40,14 +39,22 @@ db2_dialect.patch_lexer_matchers(
             "inline_comment",
             r"(--)[^\n]*",
             CommentSegment,
-            segment_kwargs={"trim_start": ("--")},
+            segment_kwargs={"trim_start": ("--"), "type": "inline_comment"},
         ),
         # In Db2, the only escape character is ' for single quote strings
         RegexLexer(
-            "single_quote", r"(?s)('')+?(?!')|('.*?(?<!')(?:'')*'(?!'))", CodeSegment
+            "single_quote",
+            r"(?s)('')+?(?!')|('.*?(?<!')(?:'')*'(?!'))",
+            CodeSegment,
+            segment_kwargs={"type": "single_quote"},
         ),
         # In Db2, there is no escape character for double quote strings
-        RegexLexer("double_quote", r'(?s)".+?"', CodeSegment),
+        RegexLexer(
+            "double_quote",
+            r'(?s)".+?"',
+            CodeSegment,
+            segment_kwargs={"type": "double_quote"},
+        ),
         # In Db2, a field could have a # pound/hash sign
         RegexLexer("code", r"[0-9a-zA-Z_#]+", CodeSegment),
     ]
