@@ -1,8 +1,9 @@
 """Implementation of Rule L021."""
 from typing import Optional
 
-from sqlfluff.core.rules.base import BaseRule, LintResult, RuleContext
-import sqlfluff.core.rules.functional.segment_predicates as sp
+from sqlfluff.core.rules import BaseRule, LintResult, RuleContext
+from sqlfluff.core.rules.crawlers import SegmentSeekerCrawler
+from sqlfluff.utils.functional import sp, FunctionalContext
 from sqlfluff.core.rules.doc_decorators import document_groups
 
 
@@ -36,21 +37,21 @@ class Rule_L021(BaseRule):
     """
 
     groups = ("all", "core")
+    crawl_behaviour = SegmentSeekerCrawler({"select_statement"})
 
     def _eval(self, context: RuleContext) -> Optional[LintResult]:
         """Ambiguous use of DISTINCT in select statement with GROUP BY."""
-        segment = context.functional.segment
-        if (
-            segment.all(sp.is_type("select_statement"))
-            # Do we have a group by clause
-            and segment.children(sp.is_type("groupby_clause"))
-        ):
+        segment = FunctionalContext(context).segment
+        # We know it's a select_statement from the seeker crawler
+        assert segment.all(sp.is_type("select_statement"))
+        # Do we have a group by clause
+        if segment.children(sp.is_type("groupby_clause")):
             # Do we have the "DISTINCT" keyword in the select clause
             distinct = (
                 segment.children(sp.is_type("select_clause"))
                 .children(sp.is_type("select_clause_modifier"))
                 .children(sp.is_type("keyword"))
-                .select(sp.is_name("distinct"))
+                .select(sp.is_keyword("distinct"))
             )
             if distinct:
                 return LintResult(anchor=distinct[0])
